# 2015-05-22 Ji Young Lee
# Written by Ji Young Lee, and edited by James Michael Krieger
# Find hot spots near high affinity residues from trajectories of 
# Druggability molecular dynamics simulations

#!/bin/bash

CL=8                # R: redius to include hot spots
CC=B                # chain ID
probe=IBTN         # output directory
hotspotsFile='../dg/dg_all_hotspots.pdb'
proteinFile='../dg/dg_protein_heavyatoms.pdb'

for arg in `seq 1 "$#"`; do
  if [[ "$arg" -eq 1 ]]; then
    CC=$1
  elif [[ "$arg" -eq 2 ]]; then
    probe=$2
  elif [[ "$arg" -eq 3 ]]; then
    CL=$3
  elif [[ "$arg" -eq 4 ]]; then
    hotspotsFile=$4
  elif [[ "$arg" -eq 5 ]]; then
    proteinFile=$5
  elif [[ "$arg" -eq 6 ]]; then
    highaffresidsdir=$6
  fi
done

if [[ $1 = "help" ]]; then
  echo "This script takes 6 arguments in the following order"
  echo "chain ID, probe type, cutoff distance between hotspots and residues,"
  echo "hotspots pdb file path, heavyatoms pdb file path, and highaffresid file path, "
  exit
fi

highaffresidsfile="$highaffresidsdir/out-$CC-$probe-highaffresid.dat"
highaffresids=`cat $highaffresidsfile`

[ ! -d "$probe-$CC" ] && mkdir $probe-$CC

### check  residues for probe

for MM in $highaffresids
do
sed -e "s/-/ -/g"       $proteinFile  > __test00
grep " $CC " __test00 > __test0
cat > ___molexe  <<EOF
awk '{if ( \$6 == $MM ) print }' __test0 > __test1
EOF
chmod 777 ___molexe
./___molexe
#rm ___*

### check hot spots trajectory
for KK in  1 # "1-6"
do
sed '1,7d'         $hotspotsFile > __test2
sed -e "s/-/ -/g"       __test2     > __test3
cp __test3 __test7
TNUM=`wc -l __test1 | awk '{print $1}'`

####LOOP#######
for (( mm = 1  ; mm <= $TNUM ; mm++ ))
do
sed -n -e "$mm,$mm p" __test1  > __test4
XX=`awk '{print $7}' __test4`
YY=`awk '{print $8}' __test4`
ZZ=`awk '{print $9}' __test4`

cat > ___molexe2  <<EOF
awk '{if ( sqrt( (\$6-($XX))*(\$6-($XX)) + (\$7-($YY))*(\$7-($YY)) + (\$8-($ZZ))*(\$8-($ZZ)) ) <= $CL ) print }' __test7 >> __test5
awk '{if ( sqrt( (\$6-($XX))*(\$6-($XX)) + (\$7-($YY))*(\$7-($YY)) + (\$8-($ZZ))*(\$8-($ZZ)) ) > $CL ) print }'  __test7  > __test6
EOF
chmod 777 ___molexe2
./___molexe2
#rm ___*

cp __test6 __test7

done
####LOOP#######

cat > ___molexe  <<EOF
awk '{printf("%-6s%5s  %-3s%6s %3d %11.3f%8.3f%8.3f%6.2f%6.2f           M\n", \$1, \$2, \$3, \$4, \$5, \$6, \$7, \$8, \$9, \$10  )}' \
 __test5 > __test8            
EOF
chmod 777 ___molexe
./___molexe
#rm ___*
#rm __test5

cp  __test8 ./$probe-$CC/out-$MM-t$KK.pdb
cat __test8 >> __out-all
cat __test8 >> __out-all2

done
mv __out-all2 ./$probe-$CC/out-$MM.pdb
grep $probe ./$probe-$CC/out-$MM.pdb > ./$probe-$CC/out2-$MM.pdb
done

awk '!seen[$0]++' __out-all > ./$probe-$CC/$probe-$CC-all.pdb
grep $probe ./$probe-$CC/$probe-$CC-all.pdb > ./$probe-$CC/$probe-$CC-all2.pdb
rm __*

grep $probe ./$probe-$CC/$probe-$CC-all.pdb >> highAffHotspots.pdb