# 2019-06-30 Bahar LAB, University of Pittsburgh  bahar@pitt.edu
# Written by James Michael Krieger
# Find high affinity residues near the dimer of interface
# with trajectory of Druggability molecular dynamics simulations

import numpy as np
import os
import sys

from prody import *
from scipy.spatial.distance import cdist

try:
  pharmmaker_dir = '/'.join(os.path.abspath(sys.argv[0]).split('/')[:-1])
  pdb = sys.argv[1]
  dcd = sys.argv[2]
except:
  pharmmaker_dir = '../pharmmaker'
  pdb = '../drugi-simulation/protein-probe.pdb'
  dcd = '../drugui-simulation/protein-probe.dcd'

start = parsePDB(pdb)
chainA = start.select('chain A')
chainB = start.select('chain B')

dists = cdist(chainA.getCoords(), chainB.getCoords())
residsA = np.unique(chainA.getResnums()[np.unique(np.argwhere(dists < 8)[:,0])])
residsB = np.unique(chainB.getResnums()[np.unique(np.argwhere(dists < 8)[:,1])])

residsA = ','.join([str(i) for i in residsA]) 
residsB = ','.join([str(i) for i in residsB])

os.system("env VMDARGS='text with blanks' vmd -dispdev text -e {0}/CORE/highaffresid.tcl -args {1} {2} A all {3} {4}".format(pharmmaker_dir, pdb, dcd, residsA, residsA))
os.system("env VMDARGS='text with blanks' vmd -dispdev text -e {0}/CORE/highaffresid.tcl -args {1} {2} B all {3} {4}".format(pharmmaker_dir, pdb, dcd, residsB, residsB))
