# 2019-06-30 Bahar LAB, University of Pittsburgh  bahar@pitt.edu
# Written by Ji Young Lee, and edited by James Michael Krieger
# Find snapshots with probes in hotspots near high affinity residues 
# with trajectory of Druggability molecular dynamics simulations

pharmmaker_dir=`readlink -e $(dirname $0)`

######### Check here  #######
# PDB file name and path
PDB='../drugui-simulation/protein-probe.pdb'
# DCD file name and path
DCD='../drugui-simulation/protein-probe.dcd'
# file containing a list of chains
chainsfile="chain-list.dat"
# file containing a list of probes
probesfile="probe-list.dat"
# cutoff between residue and probe      
CUTOFF=4.0
# cutoff between probe and hot spot
CUTOFF2=1.5
# frequency of dcd for analysis
STEP=1
######### Check here  #######

for arg in `seq 1 "$#"`; do
  if [[ "$arg" -eq 1 ]]; then
    PDB=$1
  elif [[ "$arg" -eq 2 ]]; then
    DCD=$2
  elif [[ "$arg" -eq 3 ]]; then
    chainsfile=$3
  elif [[ "$arg" -eq 4 ]]; then
    probesfile=$4
  elif [[ "$arg" -eq 5 ]]; then
    CUTOFF=$5
  elif [[ "$arg" -eq 6 ]]; then
    CUTOFF2=$6
  elif [[ "$arg" -eq 7 ]]; then
    STEP=$7
  fi
done

# protein chain ID in pdb
CHAIN=`cat $chainsfile`
[ -z "$CHAIN" ] && CHAIN=' A B ' # fill it with the default if it's empty

# probe molecule ID in pdb
PROBE=`cat $probesfile`
[ -z "$PROBE" ] && PROBE=' IPRO ACAM ACTT IPAM IBTN IMID ' # fill it with the default if it's empty

if [[ $1 = "help" ]]; then
  echo ""
  echo "This script takes up to 7 arguments in the following order"
  echo "PDB file path, DCD file path, chain ID, probe type"
  echo "cutoff for probes-residue interaction, cutoff2 for probe-hotspot distance,"
  echo "and frequency step for reading the dcd file"
  echo ""
  exit
fi

mkdir snapshot

IFS=',' read -r -a probes_array <<< $PROBE

chainNum=0
for FCHAIN in $CHAIN
do
IFS=' ' read -r -a rel_probes_array <<< $probes_array

for FPROBE in ${rel_probes_array[@]}
do

grep "$FPROBE $FCHAIN" highaffresid.dat > ____tt
sed -e "s/$FPROBE $FCHAIN/    /g" ____tt > ____tt1
RESID=`cat ____tt1 | awk '{print $0}'`

# Check Current EE 154 = Tyr151
for EE in $RESID
do

echo $pharmmaker_dir $PDB $DCD $FCHAIN $FPROBE $EE $CUTOFF $CUTOFF2 $STEP

resdir=z.$FCHAIN.$EE.$FPROBE
mkdir $resdir


# Check Current FF ############
mkdir tmp # snapshot1.tcl puts files in there
sed -e "s#APDB#$PDB#g" -e "s#ADCD#$DCD#g" -e "s/SSTEP/$STEP/g" -e "s/CUTOFF/$CUTOFF/g" -e "s/AAA/$FPROBE/g" -e "s/BBB/$EE/g" -e "s/CCC/$FCHAIN/g" $pharmmaker_dir/CORE/snapshot1.tcl > __ligb.tcl      
vmd -dispdev text -e __ligb.tcl      
mv ligbo*           $resdir

cat tmp/v*pdb > $resdir/v-com.pdb
ls  tmp/v*pdb >  __test
awk '{print $1, (NR-1) }' __test > $resdir/zlist

rm -rf tmp/
###############################


grep $FPROBE highAffHotspots.pdb > _____test0
sort -n -k10 _____test0             > __test1


TNUM=`wc -l __test1 | awk '{print $1}'`

echo "/END/{i\\" > __test3

for (( mm = 1 ; mm <= $TNUM  ; mm++ ))
do
sed -n -e "$mm,$mm p" __test1 > __test2

cat > ___molexe  <<EOF
awk '{printf("%-6s%5s  %-3s %4s%1s%4d %11.3f%8.3f%8.3f%6.2f%6.2f%13s\n", "ATOM", "$mm", "C2", "$FPROBE", "M", "$mm", \$6, \$7, \$8, \$9, \$10, "M\\\" )}' \
__test2 >> __test3
EOF
chmod 777 ___molexe
./___molexe
rm ___molexe
done
# end of mm loop

echo "END " >> __test3
echo "d "   >> __test3
echo "} "   >> __test3

sed -f __test3  $resdir/v-com.pdb > $resdir/v-com-ok.pdb

#########
for (( FF = 1 ; FF <= $TNUM  ; FF++ ))
do
sed -e "s/SSTEP/$STEP/g" -e "s/CUTOFF/$CUTOFF2/g" -e "s/AAA/resname $FPROBE and chain P and not hydrogen/g"  -e "s/BBB/resname $FPROBE and chain M and resid $FF/g" $pharmmaker_dir/CORE/snapshot2.tcl > $resdir/__ligb.tcl
cd $resdir
vmd -dispdev text -e __ligb.tcl
mv _ligbo-ok.dat ligbo-ok.$FF.dat
rm __ligb.tcl

TNNN=`wc -l zlist | awk '{print $1}'`

for (( rr = 0   ; rr <= $TNNN     ; rr++ ))
do
cat > _molexe-$rr  <<EOF
awk '{if (\$1 == $rr) print }' ligbo-ok.$FF.dat > ___test2-$rr
EOF
chmod 777 _molexe-$rr
./_molexe-$rr
rm _molexe-$rr

CRAT=`wc -l ___test2-$rr | awk '{print $1}'`

if [ $CRAT -ge 1 ]; then
cat > _molexe-$rr  <<EOF
awk '{if (\$2 == $rr) print }' zlist  > ___test3-$rr
EOF
chmod 777 _molexe-$rr
./_molexe-$rr
rm _molexe-$rr

perl -i -pe 's#tmp/v-# #g' ___test3-$rr
perl -i -pe 's/.pdb/    /g' ___test3-$rr
 
FRAME=`cat ___test3-$rr | awk '{print $1}'`
FRAMM=`cat ___test3-$rr | awk '{print $2}'`

cat > _molexe-$rr  <<EOF
awk '{if (\$1 == $FRAMM) print $FRAME , \$3, \$4, \$5, \$7, \$8, \$10 }' ligbo-ok.$FF.dat >> out-detail-res-$FF.dat
awk '{if (\$1 == $FRAME) print  }' ligbo.dat        >> out-detail-hs-$FF.dat
EOF
chmod 777 _molexe-$rr
./_molexe-$rr
rm _molexe-$rr

awk '{print $1}' ___test3-$rr >> outfr-$FF.dat

fi
done
# end of rr loop

cd ..
# coming out of $resdir

if test -f "$resdir/outfr-$FF.dat"; then
wc -l $resdir/outfr-$FF.dat  >> $resdir/outfr-count
fi

done
# end of FF loop

#########
rm    $resdir/*pdb $resdir/lig* $resdir/z* $resdir/_*

mv $resdir snapshot/

done
# end of resid loop

rm _*
done
# end of probe loop

chainNum=$((chainNum+1))
done
# end of chain loop
